==> server-api-impl-10.2.0-625.1144-sources.jar: com/xebialabs/deployit/core/rest/websockets/WebsocketsExecutorConfiguration.scala <==
package com.xebialabs.deployit.core.rest.websockets

import java.util.concurrent.{Executors, ScheduledExecutorService}

import com.xebialabs.deployit.core.config.WebSocketsConfiguration
import com.xebialabs.deployit.core.websockets.ThreadPoolTaskExecutor
import org.springframework.beans.factory.annotation.{Autowired, Qualifier}
import org.springframework.context.annotation.{Bean, Configuration}
import org.springframework.scheduling.concurrent.{ConcurrentTaskScheduler, CustomizableThreadFactory}

@Configuration
class WebsocketsExecutorConfiguration {

  @Autowired
  var websocketsConfig: WebSocketsConfiguration = _

  @Bean(destroyMethod = "shutdown")
  def websocketsExecutor: ThreadPoolTaskExecutor = {
    val threadPoolTaskExecutor = new ThreadPoolTaskExecutor()
    threadPoolTaskExecutor.setCorePoolSize(websocketsConfig.threadPool.corePoolSize)
    threadPoolTaskExecutor.setMaxPoolSize(websocketsConfig.threadPool.maxPoolSize)
    threadPoolTaskExecutor.setDaemon(websocketsConfig.threadPool.daemon)
    threadPoolTaskExecutor.setKeepAliveSeconds(websocketsConfig.threadPool.keepAliveSeconds)
    threadPoolTaskExecutor.setQueueCapacity(websocketsConfig.threadPool.queueCapacity)
    threadPoolTaskExecutor.setThreadNamePrefix("Websockets-Executor-")
    threadPoolTaskExecutor
  }

  @Bean(destroyMethod = "shutdown")
  def websocketsSchedulerExecutor: ScheduledExecutorService =
    Executors.newScheduledThreadPool(websocketsConfig.getThreadPool.corePoolSize,
    new CustomizableThreadFactory("Websockets-Scheduler-"))

  @Bean
  @Autowired
  def websocketsScheduler(@Qualifier("websocketsExecutor") threadPoolTaskExecutor: ThreadPoolTaskExecutor,
                          @Qualifier("websocketsSchedulerExecutor") scheduledExecutorService: ScheduledExecutorService
                         ) = new ConcurrentTaskScheduler(threadPoolTaskExecutor, scheduledExecutorService)
}

==> server-api-impl-10.2.0-705.2015-sources.jar: com/xebialabs/deployit/core/rest/websockets/WebsocketsExecutorConfiguration.scala <==
package com.xebialabs.deployit.core.rest.websockets

import java.util.concurrent.{Executors, ScheduledExecutorService}

import com.xebialabs.deployit.core.config.WebSocketsProperties
import com.xebialabs.deployit.core.websockets.ThreadPoolTaskExecutor
import org.springframework.beans.factory.annotation.{Autowired, Qualifier}
import org.springframework.context.annotation.{Bean, Configuration}
import org.springframework.scheduling.concurrent.{ConcurrentTaskScheduler, CustomizableThreadFactory}

@Configuration
class WebsocketsExecutorConfiguration {

  @Autowired
  var websocketsConfig: WebSocketsProperties = _

  @Bean(destroyMethod = "shutdown")
  def websocketsExecutor: ThreadPoolTaskExecutor = {
    val threadPoolTaskExecutor = new ThreadPoolTaskExecutor()
    threadPoolTaskExecutor.setCorePoolSize(websocketsConfig.threadPool.corePoolSize)
    threadPoolTaskExecutor.setMaxPoolSize(websocketsConfig.threadPool.maxPoolSize)
    threadPoolTaskExecutor.setDaemon(websocketsConfig.threadPool.daemon)
    threadPoolTaskExecutor.setKeepAliveSeconds(websocketsConfig.threadPool.keepAliveSeconds)
    threadPoolTaskExecutor.setQueueCapacity(websocketsConfig.threadPool.queueCapacity)
    threadPoolTaskExecutor.setThreadNamePrefix("Websockets-Executor-")
    threadPoolTaskExecutor
  }

  @Bean(destroyMethod = "shutdown")
  def websocketsSchedulerExecutor: ScheduledExecutorService =
    Executors.newScheduledThreadPool(websocketsConfig.getThreadPool.corePoolSize,
    new CustomizableThreadFactory("Websockets-Scheduler-"))

  @Bean
  @Autowired
  def websocketsScheduler(@Qualifier("websocketsExecutor") threadPoolTaskExecutor: ThreadPoolTaskExecutor,
                          @Qualifier("websocketsSchedulerExecutor") scheduledExecutorService: ScheduledExecutorService
                         ) = new ConcurrentTaskScheduler(threadPoolTaskExecutor, scheduledExecutorService)
}
